@@ -20,14 +20,20 @@
 #include <QtGui>
 #include <QDebug>
 
-#include "mainwindow.h"
-#include "webview.h"
+#include "webviewwindow.h"
+#include "graphicsviewwindow.h"
 
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
 
-    MainWindow window(NULL);
+#ifdef Q_WS_MAEMO_5
+    // GraphicsViewWindow window(NULL);
+    WebViewWindow window(NULL);
+#else
+    WebViewWindow window(NULL);
+#endif
+
     window.show();  
 
     return app.exec();
