@@ -30,6 +30,10 @@
 #include <QDebug>
 #include <QApplication>
 #include <QDesktopWidget>
+#include <QMenu>
+#include <QMenuBar>
+#include <QMessageBox>
+#include <QPushButton>
 
 #include "fullscreenexitbutton.h"
 
@@ -45,9 +49,6 @@ MainWindow::MainWindow(MainWindow *pParent) :
     m_webPage(this)
 {
     m_pBookmarks = NULL;
-    m_pGraphicsView = NULL;
-    m_pGWebView = NULL;
-    m_pWebView = NULL;
 
 #ifdef Q_WS_MAEMO_5
     m_pOrientationSelector = NULL;
@@ -56,8 +57,6 @@ MainWindow::MainWindow(MainWindow *pParent) :
 
     m_pParent = pParent;
 
-    m_isUsingGraphicsView = false;
-
     setWindowTitle("Macuco");
 
 
@@ -100,8 +99,9 @@ MainWindow::MainWindow(MainWindow *pParent) :
     // connect(&m_webPage, SIGNAL(linkClicked(QUrl)), this, SLOT(linkClicked(QUrl)));
     connect(&m_webPage, SIGNAL(unsupportedContent(QNetworkReply*)), this, SLOT(unsupportedContent(QNetworkReply*)));
     connect(&m_webPage, SIGNAL(downloadRequested(QNetworkRequest)), this, SLOT(downloadRequested(QNetworkRequest)));
+}
 
-
+void MainWindow::startUp() {
     if ( m_pParent ) {
         // copy settings from mainwindow
         m_zoomFactor = m_pParent->m_zoomFactor;
@@ -116,24 +116,13 @@ MainWindow::MainWindow(MainWindow *pParent) :
 #endif
 
     } else {
-	m_zoomFactor = 1;
+        m_zoomFactor = 1;
         m_pBookmarks = new QList<Bookmark>();
 
         // load settings
         loadSettings();
     }
 
-    if ( !m_pParent ) {
-        setWidget();
-        // visitUrl("http://www.crochik.com/macuco");
-        on_actionHome_triggered();
-
-    } else {
-
-        m_isUsingGraphicsView = m_pParent->m_isUsingGraphicsView;
-        setWidget();
-    }
-
 #ifdef Q_WS_X11
 #ifndef Q_WS_MAEMO_5
     // meego?
@@ -142,6 +131,9 @@ MainWindow::MainWindow(MainWindow *pParent) :
 #endif
 
     createMenu();
+
+    if ( !m_pParent ) on_actionHome_triggered();
+
     updateTitle();
 }
 
@@ -210,12 +202,6 @@ void MainWindow::createMenu() {
     pAct1->setCheckable(true);
     pAct2->setCheckable(true);
     if ( m_webPage.isIphoneUserAgent()) pAct1->setChecked(true); else pAct2->setChecked(true);
-
-    #ifdef QT_DEBUG
-        pMenu->addSeparator();
-        pMenu->addAction("Switch View", this, SLOT(switchView()));
-    #endif
-
 #endif
 
 #ifdef QT_DEBUG
@@ -224,62 +210,6 @@ void MainWindow::createMenu() {
 #endif
 }
 
-void MainWindow::switchView() {
-    m_isUsingGraphicsView = !m_isUsingGraphicsView;
-    setWidget();
-}
-
-void MainWindow::setWidget() {
-    if ( m_isUsingGraphicsView ) {
-        qDebug() << "Switch to Graphics View";
-        if ( m_pWebView ) {
-            qDebug() << ">> delete WebView";
-            delete m_pWebView; m_pWebView = NULL;
-        }
-
-        if ( !m_pGWebView ) {
-            // using graphics view
-            m_pGraphicsView = new GraphicsView(this);
-            m_pGWebView = new QGraphicsWebView();
-            m_pGraphicsView->viewportItem()->setWidget(m_pGWebView);
-            m_pGWebView->setInputMethodHints(Qt::ImhNoAutoUppercase | Qt::ImhNoPredictiveText);
-
-            connect(m_pGWebView, SIGNAL(loadStarted()), this, SLOT(showLoading()));
-            connect(m_pGWebView, SIGNAL(urlChanged(QUrl)), this, SLOT(changeUrl(QUrl)));
-            connect(m_pGWebView, SIGNAL(loadFinished(bool)), this, SLOT(hideLoading(bool)));
-        }
-
-        m_pGWebView->setPage(&m_webPage);
-        setCentralWidget(m_pGraphicsView);
-
-        if ( !m_pParent ) reload();
-        return;
-    }
-
-    qDebug() << "Switch to Web View";
-    if ( m_pGWebView ) {
-        qDebug() << ">> delete Graphics View";
-        delete m_pGWebView; m_pGWebView = NULL;
-        delete m_pGraphicsView; m_pGraphicsView = NULL;
-    }
-
-    if ( !m_pWebView ) {
-        // using web view
-        m_pWebView = new WebView(this);
-
-        connect(m_pWebView, SIGNAL(loadStarted()), this, SLOT(showLoading()));
-        connect(m_pWebView, SIGNAL(urlChanged(QUrl)), this, SLOT(changeUrl(QUrl)));
-        connect(m_pWebView, SIGNAL(loadFinished(bool)), this, SLOT(hideLoading(bool)));
-    }
-
-    // set web page
-    m_webPage.mainFrame()->setScrollBarPolicy(Qt::Vertical, Qt::ScrollBarAlwaysOff);
-    m_webPage.mainFrame()->setScrollBarPolicy(Qt::Horizontal, Qt::ScrollBarAlwaysOff);
-
-    m_pWebView->setPage(&m_webPage);
-    setCentralWidget(m_pWebView);
-}
-
 void MainWindow::aboutQt() {
     QMessageBox::aboutQt(this, "Qt");
 }
@@ -328,16 +258,6 @@ MainWindow* MainWindow::topMost() {
     return this;
 }
 
-MainWindow* MainWindow::createWindow() {
-    if ( m_pParent ) return m_pParent->createWindow();
-
-    // top most
-    MainWindow *pChild =new MainWindow(this);
-    m_children.append(pChild);
-
-    return pChild;
-}
-
 void MainWindow::loadSettings() {
     qDebug() << "load settings";
 
@@ -370,19 +290,6 @@ void MainWindow::loadSettings() {
     qDebug() << ">> done";
 }
 
-void MainWindow::updateTitle() {
-#ifdef Q_WS_MAEMO_5
-
-#else
-    QString title = m_currentUrl.isEmpty() ? "Macuco" : (m_isUsingGraphicsView?m_pGWebView->title():m_pWebView->title());
-    if ( m_webPage.isIphoneUserAgent() ) title += " - iPhone";
-
-    title += QString(" - %1%").arg(QString::number(m_zoomFactor*100, 'f', 0));
-    setWindowTitle(title);
-#endif
-
-}
-
 void MainWindow::saveSettings() {
     QSettings settings("Macuco", "Macuco");
     settings.setValue("version", SETTINGS_VERSION);
@@ -433,33 +340,12 @@ void MainWindow::changeUrl(QUrl url) {
 }
 
 void MainWindow::visitUrl(QString url) {
-
     if ( url.isNull() || url.isEmpty() ) return;
-
-    if ( m_isUsingGraphicsView ) {
-        Q_ASSERT(m_pGWebView);
-        m_pGWebView->load(QUrl::fromUserInput(url));
-    } else {
-        Q_ASSERT(m_pWebView);
-        m_pWebView->load(QUrl::fromUserInput(url));
-    }
+    visitUrl(QUrl::fromUserInput(url));
 }
 
 void MainWindow::reload() {
-    if ( m_isUsingGraphicsView ) {
-        Q_ASSERT(m_pGWebView);
-        m_pGWebView->load(m_currentUrl);
-    } else {
-        Q_ASSERT(m_pWebView);
-        m_pWebView->load(m_currentUrl);
-    }
-
-    /*
-#ifndef Q_WS_MAEMO_5
-    m_pErrorBox->hide();
-    hideOverlayOnPage();
-#end
-    */
+    visitUrl(m_currentUrl);
 }
 
 void MainWindow::adjustSizes() {
@@ -474,12 +360,10 @@ void MainWindow::zoomFit() {
     }
 }
 
-void MainWindow::resizeEvent(QResizeEvent* event)
-{
+void MainWindow::resizeEvent(QResizeEvent* event) {
     QWidget::resizeEvent(event);
 
-    // adjustSizes();
-    if ( m_pWebView || m_pGWebView )  setViewport();
+    setViewport();
 }
 
 void MainWindow::closeEvent(QCloseEvent *event)
@@ -527,19 +411,13 @@ void MainWindow::setZoom(qreal zoomFactor) {
     m_zoomFactor = zoomFactor;
     if ( m_zoomFactor>.90 && m_zoomFactor<1.1) m_zoomFactor =1;
 
+    QSizeF sz = centralWidget()->contentsRect().size();
+    sz /= m_zoomFactor;
+
+    // qDebug() << "Preferred Content Size: " << sz;
+    m_webPage.setPreferredContentsSize(sz.toSize());
+
     updateTitle();
-
-    if ( m_isUsingGraphicsView ) {
-        Q_ASSERT(m_pGWebView && m_pGraphicsView);
-        if ( !m_pGWebView ) return;
-        m_pGWebView->setZoomFactor(m_zoomFactor);
-        m_pGraphicsView->viewportItem()->resizeWebViewToFrame();
-        return;
-    }
-
-    Q_ASSERT(m_pWebView);
-    if ( !m_pWebView ) return;
-    m_pWebView->setZoomFactor(m_zoomFactor);
 }
 
 void MainWindow::keyPressEvent(QKeyEvent *event)
@@ -590,7 +468,6 @@ void MainWindow::enableWebkitAutoSize() {
 }
 
 void MainWindow::on_actionHome_triggered() {
-    m_zoomFactor = 1.5;
     visitUrl("http://www.crochik.com/macuco");
 }
 
@@ -645,8 +522,7 @@ void MainWindow::on_actionAdd_Bookmark_triggered()
 {
     BookmarkDlg dlg(this);
     dlg.setUrl(m_currentUrl.toString());
-    Q_ASSERT((m_isUsingGraphicsView && !m_pGWebView) || (!m_isUsingGraphicsView  && m_pWebView));
-    dlg.setTitle( m_isUsingGraphicsView ? m_pGWebView->title() : m_pWebView->title() );
+    dlg.setTitle( windowTitle() );
     dlg.removeBtt()->setVisible(false);
 
     if ( dlg.exec()!= QDialog::Accepted ) return;
@@ -795,7 +671,7 @@ void MainWindow::finishedRequest(QNetworkReply* reply)
 
 bool MainWindow::setViewport() {
     QMultiMap<QString, QString> meta = m_webPage.mainFrame()->metaData();
-    QList<QString> viewport = meta.values("viewport");
+    QStringList viewport(meta.values("viewport"));
     if ( viewport.isEmpty() ) {
         // keep same zoom?
         setZoom(m_zoomFactor);
@@ -803,9 +679,10 @@ bool MainWindow::setViewport() {
     }
 
     qreal zoom = m_zoomFactor;
+    QSize sz = centralWidget()->contentsRect().size();
 
     qDebug() << "ViewPort: " << viewport;
-    QStringList list = viewport[0].split(QRegExp("[;,]\\s*"), QString::SkipEmptyParts);
+    QStringList list = viewport.join(", ").split(QRegExp("[;,]\\s*"), QString::SkipEmptyParts);
     foreach (QString str, list) {
         int index = str.indexOf('=');
         if ( index<0 ) continue;
@@ -813,19 +690,26 @@ bool MainWindow::setViewport() {
         QString value = str.mid(index+1).trimmed();
 
         if ( !param.compare("width") ) {
-            qDebug()<<"Viewport.Width = " << value;
+            // qDebug()<<"Viewport.Width = " << value;
             if ( !value.compare("device-width") ) {
-                qDebug() << ">> zoom 1:1";
-                // 100%
+                // qDebug() << ">> zoom 1:1";
+#ifdef Q_WS_MAEMO_5
+                if ( m_webPage.isIphoneUserAgent() ) {
+                    setZoom(sz.width()<sz.height() ? sz.width()/320.0 : sz.width()/640.0);
+                } else {
+                    setZoom(1.5);
+                }
+#else
                 setZoom(1);
+#endif
                 return true;
             }
 
             bool ok =false;
             int w = value.toInt(&ok);
             if ( ok ) {
-                zoom = (qreal)width()/w;
-                qDebug() << ">> zoom: " << zoom;
+                zoom = (qreal)sz.width() / w;
+                // qDebug() << ">> zoom: " << zoom;
                 setZoom(zoom);
                 return true;
             }
@@ -836,7 +720,11 @@ bool MainWindow::setViewport() {
             double z = value.toDouble(&ok);
             if ( ok ) {
                 qDebug() << ">> Initial Scale: " << z;
+#ifdef Q_WS_MAEMO_5
+                zoom = z * 1.5;
+#else
                 zoom = z;
+#endif
             }
         }
     }
@@ -869,7 +757,3 @@ void MainWindow::hideLoading(bool success) {
     if ( !success ) QMessageBox::warning(this, "Loading Error", m_errors.join("\n"));
 #endif
 }
-
-QWebPage *MainWindow::page() {
-    return &m_webPage;
-}
