@@ -22,9 +22,6 @@
 #include <QtGui/QMainWindow>
 #include <QLabel>
 
-#include <QGraphicsWebView>
-#include "graphicsview.h"
-
 #ifdef Q_WS_X11 // meego?
     // ????
 #endif
@@ -33,10 +30,10 @@
     #include "pickselectoraction.h"
 #endif
 
-#include "webview.h"
 #include "bookmark.h"
 #include "webpage.h"
 
+
 namespace Ui {
     class MainWindow;
 }
@@ -51,14 +48,21 @@ public:
     void adjustSizes(); //manually adapt layout to new size
     void keyPressEvent(QKeyEvent *event);
 
-    QWebPage *page();
-    MainWindow *createWindow();
+    QWebPage *page() { return &m_webPage; }
     MainWindow *topMost();
 
-    QWebView *getWebView() { return m_pWebView; }
+    void visitUrl(QString);
 
-private:
-    void updateTitle();
+public:
+    virtual MainWindow *createWindow() =0;
+
+protected:
+    virtual void updateTitle()=0;
+    virtual void visitUrl(QUrl)=0;
+    virtual void setZoom(qreal zoomFactor);
+
+protected:
+    void startUp();
     void loadSettings();
     void saveSettings();
 
@@ -73,8 +77,6 @@ private:
     void zoomIn();
     void zoomOut();
     void zoomFit();
-    void setZoom(qreal zoomFactor);
-    void setWidget();
     void createMenu();
     bool setViewport();
 
@@ -89,7 +91,7 @@ private:
     void setAutoRotate(bool autoRotate=true);
 #endif
 
-private slots:
+protected slots:
     void on_actionUser_Agent_triggered();
     void on_actionAdd_Bookmark_triggered();
     void on_actionGo_To_triggered();
@@ -101,7 +103,7 @@ private slots:
     void onUserAgentChanged(QAction *pAction);
 
     void aboutQt();
-    void switchView();
+    // void switchView();
     void setFullScreen(bool full=true);
     void showLoading(); //called when a "loading page" is started
     void changeUrl(QUrl url); //called when the url is changed. The url will be used on the retry action
@@ -123,12 +125,7 @@ private slots:
     void fullscreen_triggered();
 #endif
 
-    //visit url
-    void visitUrl(QString);
-
-private:
-    bool            m_isUsingGraphicsView;
-
+protected:
     // mainWindow components
     QUrl            m_currentUrl;
     qreal           m_zoomFactor;
@@ -139,12 +136,6 @@ private:
     MainWindow      *m_pParent;
     QList<MainWindow *> m_children;
 
-    WebView             *m_pWebView;
-
-    // v2
-    QGraphicsWebView *m_pGWebView;
-    GraphicsView     *m_pGraphicsView;
-
 #ifdef Q_WS_MAEMO_5
     PickSelectorAction  *m_pUserAgentSelector;
     PickSelectorAction  *m_pOrientationSelector;
