@@ -43,10 +43,9 @@ WebPage::WebPage(MainWindow *pMain) {
 }
 
 QWebPage* WebPage::createWindow( WebWindowType type ) {
-    // QWebPage::WebBrowserWindow
-    // QWebPage::WebModalDialog
-
-    return m_pMainWindow->createWindow()->page();
+    Q_ASSERT(m_pMainWindow);
+    MainWindow *pWnd = m_pMainWindow->createWindow();
+    return pWnd->page();
 }
 
 void WebPage::saveCookies() {
